/* @(#)$Revision: 21.3 $ */

#ifndef ELOQDB_INCLUDED
#define ELOQDB_INCLUDED

#include "sys/types.h"

#ifdef __cplusplus
extern "C" {
#endif

/*------------------------------------------------------------------------
      idb limits
------------------------------------------------------------------------*/

#define MAX_MPASSWD       16     /* Max. length of m.password  */
#define MAX_UCL_CNT       32     /* No of security classes     */
#define MAX_PASSWD         8     /* Max. length of password    */
#define MAX_ITEM_CNT    1024     /* Max. number of items       */
#define MAX_ITEM_NAME     16     /* Max. length of item names  */
#define MAX_SET_CNT      199     /* Max. number of sets        */
#define MAX_SET_NAME      16     /* Max. length of set names   */
#define MAX_PATH_CNT      16     /* Max. number of pathes      */


/*------------------------------------------------------------------------
      idb defaults
------------------------------------------------------------------------*/

#define DEF_MAX_DB   1           /* obsolete - A.05.xx compatibility */
#define DEF_MAX_OPEN 50          /* obsolete - A.05.xx compatibility */
#define DEF_MAX_PATH 16          /* max no. of pathes / set */
#define DEF_MAX_BUF  4096        /* default user buffer size */


/*------------------------------------------------------------------------
      idb info response
------------------------------------------------------------------------*/

struct info_list {         /* 103, 104, 203, 204 */
   int count;              /* list entries   */
   int no[1];              /* list data      */
};

struct info_102 {
   char name[16];          /* item name      */
   char type;              /* item type      */
   char filler[3];         /* gap (space)    */
   int size;               /* item size      */
   int count;              /* subitem count  */
   int fmt;                /* format number  */
};

struct info_202 {
   char name[16];          /* set name       */
   char type;              /* set type       */
   char filler[3];         /* gap (space)    */
   int  rec_len;           /* record length  */
   long entries;           /* set entries    */
   long capacity;          /* set capacity   */
};

struct info_301 {
   int count;           /* list entries   */
   struct {
      int set;          /* related set    */
      int ditem;        /* detail item no */
   } path[1];
};

struct info_302 {
   int item;            /* item no        */
   int set;             /* related set/0  */
};

struct info_502 {
   char name[16];        /* iitem name     */
   int  seg_cnt;         /* segment cnt    */
   struct {
      int item;          /* item no        */
      int length;        /* seg length     */
   } seg[8];
};

union info
{
   int no;              /* used by modes 101,201 */
   struct info_list list;
   struct info_102 item;
   struct info_202 set;
   struct info_301 path_list;
   struct info_302 search_item;
   char volume[8];      /* obsolete - A.05.xx compatibility */
   struct info_502 iitem;
};


/*------------------------------------------------------------------------
      idb error codes
------------------------------------------------------------------------*/

#ifdef S_OK
#undef S_OK
#endif

#define S_OK        0      /* No error */
#define S_CANTOPEN -1      /* Unable to open database */
#define S_INUSE    -2      /* Database in use */
#define S_BADUSER  -3      /* User name not recognized */
#define S_BADPSWD  -4      /* User password does not match */
#define S_DENIED   -5      /* Permission denied */
#define S_NOSLOT   -10     /* No empty database slot */
#define S_BADID    -11     /* Bad database id */
#define S_NOLOCK   -12     /* Conflicting lock request on write attempt */
#define S_READONLY -14     /* Database opened in readonly mode */
#define S_BAD      -21     /* Bad parameter value */
#define S_NOWRITE  -23     /* No write access to data set */
#define S_BADAUTO  -24     /* Bad write attempt on automatic master */
#define S_BADMODE  -31     /* Illegal mode */
#define S_DEADLK   -35     /* A deadlock condition has been detected */
#define S_BADITEM  -52     /* Item not an accessible seach item */
#define S_BADLIST  -52     /* Bad list variable */
#define S_VERSION  -91     /* Incompatible database version */
#define S_NOCREAT  -92     /* Database requires creation */
#define S_CORRUPT  -94     /* Database may be corrupt */
#define S_NOMASTER -95     /* No master set entry for current detail */
#define S_POINTER  -96     /* Corrupt pointer value detected */

#define S_NOMEM    -120    /* Not enough memory to perform DBLOCK */
#define S_LCKM122  -122    /* Descriptor list bad */
#define S_LCKM123  -123    /* Illegal relational operator */
#define S_LCKM124  -124    /* Descriptor too short */
#define S_LCKM125  -125    /* Bad set name/number */
#define S_LCKM126  -126    /* Bad item name/numner */
#define S_LCKM127  -127    /* Attempt to lock using a compound item */
#define S_LCKM128  -128    /* Bad descriptor length for numeric item */
#define S_LCKM134  -134    /* Two descriptors conflict */
#define S_LCKM135  -135    /* Second lock not with wait option */
#define S_LCKM136  -136    /* descriptor length exceeds maximum */
#define S_LCKM137  -137    /* qualifier parameter of wrong type */

#define S_EOF       11     /* End of file reached */
#define S_DIRBOF    12     /* Directed beginning of file */
#define S_DIREOF    13     /* Directed end of file */
#define S_ENDCHAIN  15     /* End of chain reached */
#define S_NOREC     17     /* No current record or record/key not found */
#define S_BROKEN    18     /* Broken chain (only get!) */

#define S_LCK20     20     /* Database locked or contains locks */
#define S_LCK22     22     /* Dataset locked */
#define S_LCK23     23     /* Entries locked within set */
#define S_LCK24     24     /* Item conflicts with current locks */
#define S_LCK25     25     /* Entry or entries already locked */
#define S_LCKOP     27     /* Relational operator type conflict */

#define S_TXLEVEL   32     /* transaction nesting exceeds maximum */
#define S_NOTRANS   33     /* no transaction active */
#define S_TXSYNC    34     /* server transaction level out of sync */
#define S_TIMEOUT   36     /* Timeout occured during execution */

#define S_UPDATE    41     /* Cant alter search item */
#define S_DUPL      43     /* Duplicate key value */
#define S_CANTDEL   44     /* Can't delete master with non-empty chains */
#define S_BUFSPC    50     /* insufficient user buffer (eloqcore only) */
#define S_ARGTYPE   53     /* Bad argument type */
#define S_NOTFOUND  80     /* Set not created/not online */
#define S_COROPEN   94     /* Corrupt data base opened in mode 8 ** A.05.xx */
#define S_NOHEAD    100    /* No chain head for path xx */

#define S_ISAM      -800   /* Internal isam error ** A.05.xx */
#define S_DAEMON    -900   /* Daemon error ** A.05.xx */

#define S_VOLUME    -801   /* Volume failure */
#define S_VOLNODE   -802   /* Node related failure */
#define S_VOLFREC   -803   /* FixRec related problem */
#define S_BTREE     -804   /* BTREE related problem */
#define S_SYSCAT    -805   /* SysCat related problem */
#define S_SYSTEM    -806   /* System call */
#define S_LOCKDB    -807   /* locking failure */
#define S_MGMT      -808   /* management api failure */
#define S_IMAGE     -809   /* internal image failure */

/*------------------------------------------------------------------------
   Remote access supplies it's own status codes
   If a call failes, S_REMOTE will be returned in status[0] and
   status[9] will either contain errno (if above zero) or one of the
   codes below.
------------------------------------------------------------------------*/

#define S_REMOTE -700      /* remote problem */

#define S_CONNECT   -2     /* unable to connect server */
#define S_INIT      -3     /* init failed */
#define S_ARGOVFL   -4     /* client arg buffer overflow */
#define S_SEND      -5     /* problem during send */
#define S_RECEIVE   -6     /* problem during receive */
#define S_ROOT      -7     /* inconsistent ROOT structures detected */
#define S_BUFFER    -8     /* inconsistent buffer size detected */
#define S_SERVERID  -9     /* unknown server identifier */
#define S_INCAPABLE -10    /* server does not have required capabilities */


/* ------------------------------------------------------------------------
   portability type definitions
------------------------------------------------------------------------ */

#if defined(_WIN32)
/*
   assuming MS VC++ 4.x compiler
*/
#define HAS_INT64 1
typedef __int8           int8_t;     /*  8 bit signed integer */
typedef unsigned __int8  u_int8_t;   /*  8 bit unsigned integer */
typedef __int16          int16_t;    /* 16 bit signed integer */
typedef unsigned __int16 u_int16_t;  /* 16 bit unsigned integer */
typedef __int32          int32_t;    /* 32 bit signed integer */
typedef unsigned __int32 u_int32_t;  /* 32 bit unsigned integer */

#elif defined(__hpux)
/*
   HP-UX will support 32 and 64 bit compiler
   HP-UX 10.20 defines it's own type system in /usr/include/sys/_inttypes.h
*/
#if defined(__INTTYPES_INCLUDED)
typedef uint8_t u_int8_t;
typedef uint16_t u_int16_t;
typedef uint32_t u_int32_t;
#else
/* HP-UX */
typedef char             int8_t;     /*  8 bit signed integer */
typedef unsigned char    u_int8_t;   /*  8 bit unsigned integer */
typedef short            int16_t;    /* 16 bit signed integer */
typedef unsigned short   u_int16_t;  /* 16 bit unsigned integer */
typedef int              int32_t;    /* 32 bit signed integer */
typedef unsigned int     u_int32_t;  /* 32 bit unsigned integer */
#endif

#elif defined(__GNUC__)
/* gcc compiler */

#elif !defined(__GNUC__)
/* unknown compiler, eg. WIN16 */
typedef char             int8_t;     /*  8 bit signed integer */
typedef unsigned char    u_int8_t;   /*  8 bit unsigned integer */
typedef short            int16_t;    /* 16 bit signed integer */
typedef unsigned short   u_int16_t;  /* 16 bit unsigned integer */
typedef long             int32_t;    /* 32 bit signed integer */
typedef unsigned long    u_int32_t;  /* 32 bit unsigned integer */

#if defined(_WINDOWS)
/* assume WIN16 */
#define WIN16
#endif
#endif


/*------------------------------------------------------------------------
      prototypes
------------------------------------------------------------------------*/

#ifdef __hpux

/*
   The K&R compiler does not support prototypes. While everyone should
   use the ANSI compiler for anything serious, it may not be available
   because it is sold extra. So we make prototypes optional for now.
*/
#ifdef __cplusplus
#ifndef ELOQDB_PROTOTYPES
#define ELOQDB_PROTOTYPES
#endif
#else
#ifdef __STDC__
#ifndef ELOQDB_PROTOTYPES
#define ELOQDB_PROTOTYPES
#endif
#endif

#ifndef ELOQDB_PROTOTYPES
#ifndef size_t
#define size_t unsigned int
#define const /**/
#endif
#endif

#endif

#else

/*
   Here goes everything that's not HP-UX. Since K&R is a HP-UX only
   option and everyone would use a ANSI compliant compiler anyway,
   we simply enable function prototypes.
*/
#define ELOQDB_PROTOTYPES

#endif


/*
   StatusType used to be int on HP-UX and long on WIN16 platform.
   In order to preserve compatibility with existing source code, we
   currently don't make this a typedef. You should use StatusType
   instead of int or long though.
*/

#ifndef StatusType
#ifdef __hpux
#define StatusType int
#else
#define StatusType long
#endif
#endif


/*------------------------------------------------------------------------
      Externals
------------------------------------------------------------------------*/

extern StatusType idb_status;    /* Status of last idb call */
extern StatusType idb_status2;   /* Secondary status */


/* ----------------------------------------------------------------------
      idb_capabilities() capability codes
---------------------------------------------------------------------- */

#define IDBCAP_IPC          1
#define IDBCAP_TRANSACTIONS 2
#define IDBCAP_MGMT         3
#define IDBCAP_LOGON        4
#define IDBCAP_SCAN         5
#define IDBCAP_CTL          6
#define IDBCAP_HP3K         7


/* ----------------------------------------------------------------------
      idb_ctl() commands
---------------------------------------------------------------------- */

#define IDBCTL_DCSETID 1
#define IDBCTL_SCSETID 2
#define IDBCTL_GCSETID 3


/*------------------------------------------------------------------------
      prototypes
------------------------------------------------------------------------*/

#ifdef ELOQDB_PROTOTYPES
#define _p(a) a
#else
#define _p(a) ()
#endif

/*
   Compatiblity stuff for Windows API:
*/

#ifdef _WIN32
#define DBCALL _stdcall
#define DBFAR  /**/
#else
#ifdef WIN16
#define DBCALL _far _pascal
#define DBFAR  _far
#endif
#endif

#ifndef DBCALL
#define DBCALL /**/
#define DBFAR  /**/
#endif

/* classic API */

int DBCALL idb_init _p((int, int, int, int));
int DBCALL idb_exit _p((void));
int DBCALL idb_open _p((const char DBFAR *, const char DBFAR *, int, StatusType DBFAR[]));
int DBCALL idb_close _p((int, const void DBFAR *, int, StatusType DBFAR []));
int DBCALL idb_info _p((int, const void DBFAR *, int, StatusType DBFAR [], void DBFAR *));
int DBCALL idb_lock _p((int, const void DBFAR *, int, StatusType DBFAR []));
int DBCALL idb_unlock _p((int, const void DBFAR *, int, StatusType DBFAR []));
int DBCALL idb_find _p((int, const void DBFAR *, int, StatusType DBFAR [],
                    const void DBFAR *, const void DBFAR *));
int DBCALL idb_get _p((int, const void DBFAR *, int, StatusType DBFAR [],
               const void DBFAR *, char DBFAR *, const void *));
int DBCALL idb_put _p((int, const void DBFAR *, int, StatusType DBFAR [],
                   const void DBFAR *, const char DBFAR *));
int DBCALL idb_update _p((int, const void DBFAR *, int, StatusType DBFAR [],
                      const void DBFAR *, const char DBFAR *));
int DBCALL idb_delete _p((int, const void DBFAR *, int, StatusType DBFAR []));
int DBCALL idb_error _p((StatusType DBFAR [], void DBFAR *, int DBFAR *));

/* extended API */

int DBCALL idbn_info _p((int dbid, const void DBFAR *qual, int mode,
                     StatusType DBFAR status[], void DBFAR *infop, size_t infosz));
int DBCALL idbn_get _p(( int dbid, const void DBFAR *qset, int mode,
                    StatusType DBFAR status[], const void DBFAR *,
                    char DBFAR *buf, size_t bufsz, const void DBFAR *arg ));
int DBCALL idbn_put _p(( int dbid, const void DBFAR *qset, int mode,
                    StatusType DBFAR status[],
                    const void DBFAR *, const char DBFAR *buf, size_t bufsz ));
int DBCALL idbn_update _p(( int dbid, const void DBFAR *qset, int mode,
                       StatusType DBFAR status[],
                       const void DBFAR *, const char DBFAR *buf, size_t bufsz ));
int DBCALL idbn_error _p((StatusType DBFAR [], void DBFAR *, size_t, int DBFAR *));

/* mode 13 API */

int DBCALL idb_create _p((int dbid, int mode, StatusType DBFAR status[],
                          int count, int DBFAR []));
int DBCALL idb_erase _p((int dbid, int mode, StatusType DBFAR status[],
                          int count, int DBFAR []));
int DBCALL idb_purge _p((int dbid, int mode, StatusType DBFAR status[],
                          int count, int DBFAR []));

/* miscellaneous */

int DBCALL idb_capabilities _p((int, int));
int DBCALL idb_ctl _p((int, int));
int DBCALL idb_logon _p((const char DBFAR *user, const char DBFAR *pswd));
int DBCALL idb_begin _p((const char DBFAR *comment, int mode, StatusType DBFAR status[]));
int DBCALL idb_rollback _p((u_int32_t id, int mode, StatusType DBFAR status[]));
int DBCALL idb_commit _p((int mode, StatusType DBFAR status[]));

#undef _p

#ifdef __cplusplus
}
#endif

#endif   /* ~ELOQDB_INCLUDED */
