/* -----------------------------------------------------------------------

   (C) Copyright Marxmeier Software GmbH 1998,1999. All rights reserved.

   Project:  HP3K API
   File:     image3k.h
   Function: IMAGE3K API
   $Id$

   TODO: Add DBAUTH function (EQ extension) to allow EQ aware programs
         to make use of the db security subsystem

   If IMAGE3K_STRICT_PROTOTYPES is defined than stricter function
   prototypes are provided (short * vs. void * arguments).

   Edit history:
   15.09.1998, mm  - fixed prototypes
   08.04.1999, mm  - stub prototypes
   14.04.1999, mm  - lwc entry points

----------------------------------------------------------------------- */

#ifndef IMAGE3K_H
#define IMAGE3K_H

#if defined(__cplusplus)
extern "C" {
#endif

/*
   define ELOQUENCE symbol so EQ aware programs programs can #ifdef
   some stuff ...
*/
#define ELOQUENCE 1


/*
   HP3K intrinsic numbers.
   Not sure if they need to be public, however it should not hurt
   since the symbols are rather unlikely to be used otherwise
*/
enum hp3k_Intrinsic_ID {
   DBOPEN_INTRINSIC_ID    = 401,
   DBINFO_INTRINSIC_ID    = 402,
   DBCLOSE_INTRINSIC_ID   = 403,
   DBFIND_INTRINSIC_ID    = 404,
   DBGET_INTRINSIC_ID     = 405,
   DBUPDATE_INTRINSIC_ID  = 406,
   DBPUT_INTRINSIC_ID     = 407,
   DBDELETE_INTRINSIC_ID  = 408,
   DBLOCK_INTRINSIC_ID    = 409,
   DBUNLOCK_INTRINSIC_ID  = 410,
   DBCONTROL_INTRINSIC_ID = 411,
   DBBEGIN_INTRINSIC_ID   = 412,
   DBEND_INTRINSIC_ID     = 413,
   DBMEMO_INTRINSIC_ID    = 414,
   DBEXPLAIN_INTRINSIC_ID = 418,
   DBERROR_INTRINSIC_ID   = 419,
   DBXBEGIN_INTRINSIC_ID  = 420,
   DBXEND_INTRINSIC_ID    = 421,
   DBXUNDO_INTRINSIC_ID   = 422
};


/*
   Compatiblity stuff for Win32 API
*/
#ifdef _WIN32
#define DBCALL _stdcall
#else
#define DBCALL /**/
#endif


/*
   IMAGE3K API prototypes
*/

#ifdef IMAGE3K_STRICT_PROTOTYPES
#define HP3K_I16 short
#else
#define HP3K_I16 void
#endif

void DBCALL dbopen(void *base, const void *pswd, const HP3K_I16 *modep,
                  HP3K_I16 *status);
void DBCALL dbclose(void *base, const void *dset, const HP3K_I16 *modep,
                   HP3K_I16 *status);

void DBCALL dbcontrol(const void *base, const void *qualifier,
                     const HP3K_I16 *modep, HP3K_I16 *status);
void DBCALL dbinfo(const void *base, const void *qualifier, const HP3K_I16 *modep,
                  HP3K_I16 *status, void *buffer);

void DBCALL dbput(const void *base, const void *dset, const HP3K_I16 *modep,
                 HP3K_I16 *status, const void *list, void *buffer);
void DBCALL dbdelete(const void *base, const void *dset, const HP3K_I16 *modep,
                    HP3K_I16 *status);
void DBCALL dbupdate(const void *base, const void *dset, const HP3K_I16 *modep,
                    HP3K_I16 *status, const void *list, const void *buffer);
void DBCALL dbget(const void *base, const void *dset, const HP3K_I16 *modep,
                 HP3K_I16 *status, const void *list, void *buffer,
                 const void *argument);
void DBCALL dbfind(const void *base, const void *dset, const HP3K_I16 *modep,
                  HP3K_I16 *status, const void *item, const void *argument);

void DBCALL dblock(const void *base, const void *qualifier, const HP3K_I16 *modep,
                  HP3K_I16 *status);
void DBCALL dbunlock(const void *base, const void *qualifier, const HP3K_I16 *modep,
                    HP3K_I16 *status);

void DBCALL dbbegin(const void *base, const void *text, const HP3K_I16 *modep,
                   HP3K_I16 *status, const void *textlenp);
void DBCALL dbend(const void *base, const void *text, const HP3K_I16 *modep,
                 HP3K_I16 *status, const void *textlenp);
void DBCALL dbmemo(const void *base, const void *text, const HP3K_I16 *modep,
                  HP3K_I16 *status, const void *textlenp);

void DBCALL dbxbegin(const void *base, const void *text, const HP3K_I16 *modep,
                    HP3K_I16 *status, const void *textlenp);
void DBCALL dbxend(const void *base, const void *text, const HP3K_I16 *modep,
                  HP3K_I16 *status, const void *textlenp);
void DBCALL dbxundo(const void *base, const void *text, const HP3K_I16 *modep,
                   HP3K_I16 *status, const void *textlenp);

void DBCALL dbexplain(const HP3K_I16 *status);
void DBCALL dberror(const HP3K_I16 *status, void *buffer, const void *textlenp);
void DBCALL dbauth(void *base, const void *pswd, HP3K_I16 *status);

/*
   In order to be able to catch all function calls w/o making
   dld stunts, the same functions are available with a leading
   underscore which implement the functionality.
*/

void DBCALL _dbopen(void *base, const void *pswd, const void *modep,
                  void *status);
void DBCALL _dbclose(void *base, const void *dset, const void *modep,
                   void *status);

void DBCALL _dbcontrol(const void *base, const void *qualifier,
                     const void *modep, void *status);
void DBCALL _dbinfo(const void *base, const void *qualifier, const void *modep,
                  void *status, void *buffer);

void DBCALL _dbput(const void *base, const void *dset, const void *modep,
                 void *status, const void *list, void *buffer);
void DBCALL _dbdelete(const void *base, const void *dset, const void *modep,
                    void *status);
void DBCALL _dbupdate(const void *base, const void *dset, const void *modep,
                    void *status, const void *list, const void *buffer);
void DBCALL _dbget(const void *base, const void *dset, const void *modep,
                 void *status, const void *list, void *buffer,
                 const void *argument);
void DBCALL _dbfind(const void *base, const void *dset, const void *modep,
                  void *status, const void *item, const void *argument);

void DBCALL _dblock(const void *base, const void *qualifier, const void *modep,
                  void *status);
void DBCALL _dbunlock(const void *base, const void *qualifier, const void *modep,
                    void *status);

void DBCALL _dbbegin(const void *base, const void *text, const void *modep,
                   void *status, const void *textlenp);
void DBCALL _dbend(const void *base, const void *text, const void *modep,
                 void *status, const void *textlenp);
void DBCALL _dbmemo(const void *base, const void *text, const void *modep,
                  void *status, const void *textlenp);

void DBCALL _dbxbegin(const void *base, const void *text, const void *modep,
                    void *status, const void *textlenp);
void DBCALL _dbxend(const void *base, const void *text, const void *modep,
                  void *status, const void *textlenp);
void DBCALL _dbxundo(const void *base, const void *text, const void *modep,
                   void *status, const void *textlenp);

void DBCALL _dbexplain(const void *status);
void DBCALL _dberror(const void *status, void *buffer, const void *textlenp);
void DBCALL _dbauth(void *base, const void *pswd, HP3K_I16 *status);

/*
   Translate upc IMAGE procedure names to lwc symbols.
   Intrinsics are not not case sensitive but mixed case symbols 
   are not handled for now.
*/

#define DBBEGIN dbbegin
#define DBCLOSE dbclose
#define DBCONTROL dbcontrol
#define DBDELETE dbdelete
#define DBEND dbend
#define DBERROR dberror
#define DBEXPLAIN dbexplain
#define DBFIND dbfind
#define DBGET dbget
#define DBINFO dbinfo
#define DBLOCK dblock
#define DBMEMO dbmemo
#define DBOPEN dbopen
#define DBPUT dbput
#define DBUNLOCK dbunlock
#define DBUPDATE dbupdate
#define DBXBEGIN dbxbegin
#define DBXEND dbxend
#define DBXUNDO dbxundo
#define DBAUTH dbauth

#if defined(__cplusplus)
}
#endif

#endif /* IMAGE3K_H */
