!! EQ:DEFAULTS
!! @(#) defaults.eq, 05.02.99, A.06.20
/* ----------------------------------------------------------------------

   eq.def - defaults & models for eq xlg

---------------------------------------------------------------------- */

dialog EqDialog
{
  .xraster 12;
  .yraster 12;
}

// ======================================================================
//
//    R E S O U R C E S
//
// ======================================================================

// ======================================================================
// Callback Functions
// ----------------------------------------------------------------------
// HP ELOQUENCE needs this functions to keep track of current
// object state. If you don't care about compatibility, you may
// delete them.
//
// EqPushButtonCB  - If a pushbutton gets selected
// EqCheckBoxCB    - If a checkbox is (de-) activated
// EqRadioButtonCB - If a radiobutton is (de-) activated
// EqEditTextCB    - If a edittext looses focus
// ----------------------------------------------------------------------
// EqExitEventLoop - This will terminate DLG DO statement with
//                   given object and rule value.
//                   It will return upon next DLG DO statement.
// ----------------------------------------------------------------------

function callback EqPushButtonCB() for select;
function callback EqCheckBoxCB() for activate, deactivate;
function callback EqRadioButtonCB() for activate;
function callback EqEditTextCB() for deselect;
function callback EqListBoxCB() for select, dbselect;

function void EqExitEventLoop( object, integer );
function boolean EqCallBack( string, object, integer );
function void EqRestorePopup();

// ======================================================================
// Help Subsystem
// ----------------------------------------------------------------------
// EqHelpOnObject  - show object help
// EqHelpOnTag     - display arbitrary help
// EqHelpViewFile  - view text file in help window
// EqHelpManPage   - view man page in help window
//
// EqHelpPath      - help document path relative to HelpBaseURL (eloq.ini)
//
// Most function needs an object function argument to locate the
// help volume associated with dialog.
// The help volume may be defined using variable EqHelpPath.
// ----------------------------------------------------------------------

config variable string EqHelpPath;

function boolean EqHelpOnObject(object input);
function boolean EqHelpOnTag(object input, string input);
function boolean EqHelpViewFile(string input);
function boolean EqHelpManPage(string input);

// ======================================================================
// Font Resources
// ----------------------------------------------------------------------
// The following font defines the basic layout of the dialog.
// NOTE: BaseFont should be a fixed space font.
// ----------------------------------------------------------------------

// Base Font is used to calculate all sizes and positions.
font BaseFont {
    0: "*-courier-medium-r-normal--14-*-hp-roman8";
    1: "10.Courier" y:=*110%+0;
}

// Normal Font is used to display all text fields
font NormalFont {
    0: "*-courier-medium-r-normal--14-*-hp-roman8";
    1: "10.Courier";
}

// Bold Font is not used
font BoldFont {
    0: "*-courier-bold-r-normal--14-*-hp-roman8";
    1: "10.Courier",0,bold;
}

// Italic Font is not used
font ItalicFont {
    0: "*-courier-medium-i-normal--14-*-hp-roman8";
    1: "10.Courier",0,italic;
}

// ======================================================================
// Keyboard accelerators
// ----------------------------------------------------------------------
// The following accelerators are required by HP ELOQUENCE to
// map the keyboard behaviour.
// If you don't need them, you may delete them.
// ----------------------------------------------------------------------

accelerator EqKbF1 F1;
accelerator EqKbF2 F2;
accelerator EqKbF3 F3;
accelerator EqKbF4 F4;
accelerator EqKbF5 F5;
accelerator EqKbF6 F6;
accelerator EqKbF7 F7;
accelerator EqKbF8 F8;
accelerator EqKbF9 F9;
accelerator EqKbCR Return;

accelerator EqKbSelect "space";

// ======================================================================
// Some fancy colors.
// None of this is required.
// ----------------------------------------------------------------------

// Non Editable background

color ColWin {
    0: rgb(192,192,192), grey(192), white;
    1: rgb(192,192,192), grey(192), white;
}

// EditText Background

color ColInput {
    0: rgb(224,224,224), grey(224), white;
    1: "WHITE",grey(255), white;
}

color ColBlack "BLACK", grey(0), white;
color ColWhite "WHITE", grey(0), white;
color ColRed "RED", grey(0), white;
color ColGreen "GREEN", grey(0), white;
color ColBlue "BLUE", grey(0), white;
color ColYellow "YELLOW", grey(0), white;

// ======================================================================
//    D E F A U L T S
// ======================================================================

!! EQ:DEFAULTS

default canvas
{
  .visible true;
  .width 5;
  .height 5;
  .posraster true;
  .sizeraster true;
  .borderwidth 2;
}

// ----------------------------------------------------------------------

default checkbox
{
  .visible true;
  .posraster true;
  .sizeraster true;
  .text "Checkbox";
  .function EqCheckBoxCB;
  .font NormalFont;
  integer EqRule := 0;
  integer EqRuleOverride := 0;
  .bgc ColWin;
  .fgc ColBlack;
}

// ----------------------------------------------------------------------

default edittext
{
  .visible true;
  .font NormalFont;
  .posraster true;
  .sizeraster true;
//  .maxchars 0;
//  .height 1;
  .borderwidth 0;
  integer EqRule := 0;
  integer EqRuleOverride := 0;
  .function EqEditTextCB;
  .bgc ColInput;
  .fgc ColBlack;
}

// ----------------------------------------------------------------------

default listbox
{
  .visible true;
  .font NormalFont;
  .width 40;
  .height 5;
  .posraster true;
  .sizeraster true;
  .firstchar 1;
  integer EqRule := 0;
  integer EqRuleOverride := 0;
  integer EqActiveline := 0;
  .function EqListBoxCB;
  .bgc ColWin;
  .fgc ColBlack;
  .borderwidth 1;
}

// ----------------------------------------------------------------------

default image
{
  .visible true;
  .width 0;
  .height 0;
  .posraster true;
  .sizeraster true;
  .font NormalFont;
  integer EqRule := 0;
  integer EqRuleOverride := 1;
}

// ----------------------------------------------------------------------

default menubox
{
  .visible true;
}

// ----------------------------------------------------------------------

default menuitem
{
  .visible true;
}

// ----------------------------------------------------------------------

default menusep
{
  .visible true;
}

// ----------------------------------------------------------------------

default messagebox
{
  .button[1] button_ok;
  .button[2] button_cancel;
  .defbutton 1;
}

// ----------------------------------------------------------------------

default poptext
{
  .visible true;
  .font NormalFont;
  .width 40;
  .posraster true;
  .sizeraster true;
  integer EqRule := 0;
  integer EqRuleOverride := 0;
  integer EqActiveline := 0;
  .function EqListBoxCB;
  .bgc ColWin;
  .fgc ColBlack;
}

// ----------------------------------------------------------------------

default groupbox
{
  .visible true;
  .width 20;
  .height 5;
  .posraster true;
  .sizeraster true;
  .reffont BaseFont;
//  .borderwidth 1;
  .bgc ColWin;
  .fgc ColBlack;
}

// ----------------------------------------------------------------------

default pushbutton
{
  .visible true;
//  .width 12;
  .posraster true;
  .sizeraster true;
  .function EqPushButtonCB;
  .font NormalFont;
  integer EqRule := 0;
  integer EqRuleOverride := 1;
  .bgc ColWin;
  .fgc ColBlack;
//  .style 0;
  .text "PushButton";
}

// ----------------------------------------------------------------------

default radiobutton
{
  .visible true;
  .font NormalFont;
  .posraster true;
  .sizeraster true;
  .text "Radiobutton";
  .function EqRadioButtonCB;
  integer EqRule := 0;
  integer EqRuleOverride := 0;
  .bgc ColWin;
  .fgc ColBlack;
}

// ----------------------------------------------------------------------

default rectangle
{
  .visible true;
  .width 5;
  .height 5;
  .posraster true;
  .sizeraster true;
  .borderwidth 1;
  .filled true;
}

// ----------------------------------------------------------------------

default scrollbar
{
  .visible true;
  .font NormalFont;
  .width 0;
  .height 5;
  .posraster true;
  .sizeraster true;
  .linemotion 1;
  .pagemotion 1;
}

// ----------------------------------------------------------------------

default statictext
{
  .visible true;
  .sensitive false;
  .posraster true;
  .sizeraster true;
  .text "Statictext";
  .font NormalFont;
  .bgc ColWin;
  .fgc ColBlack;
}

// ----------------------------------------------------------------------

default tablefield
{
  .visible true;
  .font NormalFont;
  .width 20;
  .height 5;
  .posraster true;
  .sizeraster true;
  .editpos true;
  .colcount 5;
  .rowcount 5;
  .colfirst 1;
  .rowfirst 1;
  .colwidth[0] 20;
  .rowheight[0] 1;
  .reffont BaseFont;
}

// ----------------------------------------------------------------------

default window
{
//  .visible true;
  .visible false;
  .font NormalFont;
  .width 60;
  .height 10;
  .posraster false;
  .sizeraster true;
//  .reffont FontNormal;
  .reffont BaseFont;
  .closeable false;
  .dialogbox true;
  .moveable true;
  .sizeable false;
  .iconic false;
  .iconifyable true;
  .title "Window";
// This is necessary to handle eloquence style like accelerators.
// [1] = CR, [2]..[9] = F1..8, [10] = reserved (F9)
   integer EqKbRule[10];
  .bgc ColWin;
  .fgc ColBlack;
// Windoze CTL3D
// .options[opt_no_clipping] true;
// .options[opt_use_3d] true;
}

!! EQ:ENDDEFAULTS

// ======================================================================
//
//    P O P U P
//
// ======================================================================

!! EQ:OBJECT

window EqPopup
{
  .visible false;
  .width 43;
  .height 9;
  .sizeable true;
  .title "HP Eloquence";
  child pushbutton EqPB1
  {
    .xleft 0;
    .yauto -1;
//  .height 1;
    .ybottom 0;
    .text "PB1";
  }
  child pushbutton EqPB2
  {
    .xleft 4;
    .yauto -1;
//  .height 1;
    .ybottom 0;
    .text "PB2";
  }
  child pushbutton EqPB3
  {
    .xleft 8;
    .yauto -1;
//  .height 1;
    .ybottom 0;
    .text "PB3";
  }
  child pushbutton EqPB4
  {
    .xleft 12;
    .yauto -1;
//  .height 1;
    .ybottom 0;
    .text "PB4";
  }
  child pushbutton EqPB5
  {
    .xleft 16;
    .yauto -1;
//  .height 1;
    .ybottom 0;
    .text "PB5";
  }
  child edittext EqMsg
  {
    .sensitive false;
    .active false;
    .xauto 0;
    .xleft 0;
    .yauto 0;
    .ytop 0;
    .ybottom 1;
    .multiline true;
//  .content "Multiline Message Box !!!\nLine #1\nLine #2\nLine #3";
//  .focusable true;
    .editable false;
    .hsb_visible false;
    .vsb_visible false;
    .endsel 0;
  }
}

!! EQ:ENDOBJECT

on EqPopup.EqPB1 select, key EqKbCR {
   EqPopup.visible := false;
   updatescreen();
// EqRestorePopup();
   EqExitEventLoop( this, 1 );
}

on EqPopup.EqPB2 select, key EqKbCR {
   EqPopup.visible := false;
   updatescreen();
// EqRestorePopup();
   EqExitEventLoop( this, 2 );
}

on EqPopup.EqPB3 select, key EqKbCR {
   EqPopup.visible := false;
   updatescreen();
// EqRestorePopup();
   EqExitEventLoop( this, 3 );
}

on EqPopup.EqPB4 select, key EqKbCR {
   EqPopup.visible := false;
   updatescreen();
// EqRestorePopup();
   EqExitEventLoop( this, 4 );
}

on EqPopup.EqPB5 select, key EqKbCR {
   EqPopup.visible := false;
   updatescreen();
// EqRestorePopup();
   EqExitEventLoop( this, 5 );
}

// ======================================================================
//    R U L E S
// ======================================================================

// Entry required by cvdlg

rule boolean EqSaveDialog( string Fname ) {
   save( this, Fname );
   return(false);
}

// image
// NOTE: CR on image has some kind of precedence over CR rule

on IMAGE select, key EqKbCR {
   if( this.EqRule ) then
      EqExitEventLoop( this, this.EqRule );
   endif
}

// pushbutton
// NOTE: CR on pushbutton has some kind of precedence over CR rule

on PUSHBUTTON select, key EqKbCR {
   if( this.EqRule ) then
      EqExitEventLoop( this, this.EqRule );
   endif
}

// checkbox: state changed

on CHECKBOX activate, deactivate {
   if( this.EqRule ) then
      EqExitEventLoop( this, this.EqRule );
   endif
}

// radiobutton: state changed

on RADIOBUTTON activate {
   if( this.EqRule ) then
      EqExitEventLoop( this, this.EqRule );
   endif
}

// listbox
// This rule allows to browse listbox content by keybd even on a graphical ui

on LISTBOX dbselect {
   this.EqActiveline := this.activeitem;
   if( this.EqRule ) then
      EqExitEventLoop( this, this.EqRule );
   endif
}

on LISTBOX key EqKbSelect {
   this.EqActiveline := this.activeitem;
   if( this.EqRule ) then
      EqExitEventLoop( this, this.EqRule );
   endif
}

// poptext: selected line has changed

on POPTEXT select {
   this.EqActiveline := this.activeitem;
   if( this.EqRule ) then
      EqExitEventLoop( this, this.EqRule );
   endif
}

// edittext: deselected

on EDITTEXT deselect {
   variable integer RuleOverride := 0;
   if (this.window.focus <> null) then
      if( typeof( this.window.focus.EqRuleOverride ) = integer ) then
         RuleOverride := this.window.focus.EqRuleOverride;
      endif;
   endif;
   if( RuleOverride = 0 ) then
      if( this.EqRule ) then
         EqExitEventLoop( this, this.EqRule );
      endif
   endif
}

// edittext: deselected by CR

on EDITTEXT deselect_enter {
   if (typeof(this.window.EqKbRule[1]) = integer) then
      if(this.window.EqKbRule[1]) then
         EqExitEventLoop( this, this.window.EqKbRule[1] );
      endif
   endif
}

// keyboard events on window

on WINDOW key EqKbCR
{
   if (typeof(this.window.EqKbRule[1]) = integer) then
      if this.window.EqKbRule[1] then
         EqExitEventLoop(this, this.window.EqKbRule[1]);
      endif
   endif
}
on WINDOW key EqKbF1
{
   if this.window.EqKbRule[2] then
      EqExitEventLoop(this, this.window.EqKbRule[2]);
   endif
}
on WINDOW key EqKbF2
{
   if this.window.EqKbRule[3] then
      EqExitEventLoop(this, this.window.EqKbRule[3]);
   endif
}
on WINDOW key EqKbF3
{
   if this.window.EqKbRule[4] then
      EqExitEventLoop(this, this.window.EqKbRule[4]);
   endif
}
on WINDOW key EqKbF4
{
   if this.window.EqKbRule[5] then
      EqExitEventLoop(this, this.window.EqKbRule[5]);
   endif
}
on WINDOW key EqKbF5
{
   if this.window.EqKbRule[6] then
      EqExitEventLoop(this, this.window.EqKbRule[6]);
   endif
}
on WINDOW key EqKbF6
{
   if this.window.EqKbRule[7] then
      EqExitEventLoop(this, this.window.EqKbRule[7]);
   endif
}
on WINDOW key EqKbF7
{
   if this.window.EqKbRule[8] then
      EqExitEventLoop(this, this.window.EqKbRule[8]);
   endif
}
on WINDOW key EqKbF8
{
   if this.window.EqKbRule[9] then
      EqExitEventLoop(this, this.window.EqKbRule[9]);
   endif
}

// help on object

on WINDOW help
{
   EqHelpOnObject(this);
}

// EQ:ENDDEFAULTS -------------------------------------------------------------
